==> ceresdb_client-0.1.1.tar.gz: ceresdb_client-0.1.1/README.md <==
# CeresDB Python Client

![License](https://img.shields.io/badge/license-Apache--2.0-green.svg)
[![CI](https://github.com/CeresDB/ceresdb-client-py/actions/workflows/ci.yml/badge.svg)](https://github.com/CeresDB/ceresdb-client-py/actions/workflows/ci.yml)
[![OpenIssue](https://img.shields.io/github/issues/CeresDB/ceresdb-client-py)](https://github.com/CeresDB/ceresdb-client-py/issues)
[![Slack](https://badgen.net/badge/Slack/Join%20CeresDB/0abd59?icon=slack)](https://join.slack.com/t/ceresdbcommunity/shared_invite/zt-1au1ihbdy-5huC9J9s2462yBMIWmerTw)

## Introduction
The python client for [CeresDB](https://github.com/CeresDB/ceresdb).

[CeresDB](https://github.com/CeresDB/ceresdb) is a high-performance, distributed, schema-less, cloud native time-series database that can handle both time-series and analytics workloads.

## Support features
- [x] Query
- [x] Write

An [example](https://github.com/CeresDB/ceresdb-client-py/blob/main/examples/read_write.py) is provided to show how to access CeresDB.

## Contributing
Any contribution is welcome!

Read our [Contributing Guide](https://github.com/CeresDB/ceresdb/blob/main/CONTRIBUTING.md) and make your first contribution!

## License
Under [Apache License 2.0](./LICENSE).

## Community and support
- Join the user group on [Slack](https://join.slack.com/t/ceresdbcommunity/shared_invite/zt-1au1ihbdy-5huC9J9s2462yBMIWmerTw)
- Join the user group on WeChat [WeChat QR code](https://github.com/CeresDB/assets/blob/main/WeChatQRCode.jpg)
- Join the user group on DingTalk: 44602802

==> ceresdb_client-1.0.0.tar.gz: ceresdb_client-1.0.0/README.md <==
# CeresDB Python Client

![License](https://img.shields.io/badge/license-Apache--2.0-green.svg)
[![CI](https://github.com/CeresDB/ceresdb-client-py/actions/workflows/ci.yml/badge.svg)](https://github.com/CeresDB/ceresdb-client-py/actions/workflows/ci.yml)
[![OpenIssue](https://img.shields.io/github/issues/CeresDB/ceresdb-client-py)](https://github.com/CeresDB/ceresdb-client-py/issues)
[![PyPI](https://img.shields.io/pypi/v/ceresdb-client.svg)](https://pypi.org/project/ceresdb-client)
[![Slack](https://badgen.net/badge/Slack/Join%20CeresDB/0abd59?icon=slack)](https://join.slack.com/t/ceresdbcommunity/shared_invite/zt-1au1ihbdy-5huC9J9s2462yBMIWmerTw)

## Introduction
The python client for [CeresDB](https://github.com/CeresDB/ceresdb).

[CeresDB](https://github.com/CeresDB/ceresdb) is a high-performance, distributed, schema-less, cloud native time-series database that can handle both time-series and analytics workloads.

## Support features
- [x] Query
- [x] Write

An [example](https://github.com/CeresDB/ceresdb-client-py/blob/main/examples/read_write.py) is provided to show how to access CeresDB.

## Installation

```bash
pip install ceresdb-client
```

## Contributing
Any contribution is welcome!

Read our [Contributing Guide](https://github.com/CeresDB/ceresdb/blob/main/CONTRIBUTING.md) and make your first contribution!

## License
Under [Apache License 2.0](./LICENSE).

## Community and support
- Join the user group on [Slack](https://join.slack.com/t/ceresdbcommunity/shared_invite/zt-1au1ihbdy-5huC9J9s2462yBMIWmerTw)
- Join the user group on WeChat [WeChat QR code](https://github.com/CeresDB/assets/blob/main/WeChatQRCode.jpg)
- Join the user group on DingTalk: 44602802
